@@ -1,6 +1,6 @@
 /* session-func.c -- Functions for working with SSH session.
  *
- * Copyright (C) 2013-2023 Artyom V. Poptsov <poptsov.artyom@gmail.com>
+ * Copyright (C) 2013-2024 Artyom V. Poptsov <poptsov.artyom@gmail.com>
  *
  * This file is part of Guile-SSH.
  *
@@ -81,6 +81,10 @@ static gssh_symbol_t session_options[] = {
   { "public-key-accepted-types", SSH_OPTIONS_PUBLICKEY_ACCEPTED_TYPES },
 #endif
 
+#if HAVE_LIBSSH_0_10
+  {"rsa-min-size",        SSH_OPTIONS_RSA_MIN_SIZE       },
+#endif
+
   { "callbacks",          GSSH_OPTIONS_CALLBACKS         },
   { NULL,                 -1 }
 };
@@ -399,6 +403,12 @@ set_option (SCM scm_session, gssh_session_t* sd, int type, SCM value)
         break;
 #endif
 
+#if HAVE_LIBSSH_0_10
+    case SSH_OPTIONS_RSA_MIN_SIZE:
+        return set_int32_opt (session, type, value);
+        break;
+#endif
+
     default:
       guile_ssh_error1 ("session-set!",
                         "Operation is not supported yet: %a~%",
