@@ -45,7 +45,6 @@
 (define topdir (getenv "abs_top_srcdir"))
 
 (define log    (test-runner-aux-value (test-runner-current)))
-(define *server-thread* #f)
 
 
 ;;; Helper procedures and macros
@@ -77,7 +76,10 @@
    (lambda ()
      (call-with-connected-session
       (lambda (session)
-        (connected? session))))))
+        (and (connected? session)
+             (begin
+               (disconnect! session)
+               (not (connected? session)))))))))
 
 (test-equal-with-log "get-protocol-version"
   2
@@ -90,7 +92,9 @@
    (lambda ()
      (call-with-connected-session
       (lambda (session)
-        (get-protocol-version session))))))
+        (let ((version (get-protocol-version session)))
+          (disconnect! session)
+          version))))))
 
 (test-assert-with-log "authenticate-server, not-known"
   'not-known
@@ -410,7 +414,7 @@
      (call-with-connected-session
       (lambda (session)
         (authenticate-server session)
-        (let ((prvkey (private-key-from-file %rsakey)))
+        (let ((prvkey (private-key-from-file %ecdsakey)))
           (userauth-public-key! session prvkey)))))))
 
 
@@ -714,6 +718,47 @@
                                     "res: ~a" res)
                     (equal? res vect))))))))))
 
+;; This test checks if the client side is able to handle unexpected close of
+;; the channel from the remote side.
+;;
+;; When a client tries to read from a channel that is abruptly closed by the
+;; remote side (e.g. when a remote side is crashed) the reading procedure must
+;; return EOF without issuing an error or a segmentation fault.
+(test-assert-with-log "data transferring, remote side abruptly closed"
+  (run-client-test
+
+   ;; server
+   (lambda (server)
+     (use-modules (rnrs bytevectors)
+                  (rnrs io ports))
+     (start-server/dt-test server
+                           (lambda (channel)
+                             (let ((v (get-bytevector-n channel 10)))
+                               (put-bytevector channel v)
+                               (kill (getpid) SIGKILL)))))
+
+   ;; client
+   (lambda ()
+     (call-with-connected-session/channel-test
+      (lambda (session)
+        (let* ((vect-size 10)
+               (channel   (make-channel/dt-test session))
+               (vect      (make-bytevector vect-size 42)))
+          (put-bytevector channel vect)
+          (let loop ((data   '())
+                     (result (get-bytevector-n channel (/ vect-size 2))))
+            (if (eof-object? result)
+                data
+                (catch #t
+                  (lambda ()
+                    (loop (cons result data)
+                          (get-bytevector-n channel (/ vect-size 2))))
+                  (lambda err
+                    (format (current-error-port)
+                            "    unexpected error: ~a~%"
+                            err)
+                    #f))))))))))
+
 
 ;;;
 ;;; Channels
@@ -743,8 +788,10 @@
 
 ;;;
 
+(define exit-status (test-runner-fail-count (test-runner-current)))
+
 (test-end "client-server")
 
-(exit (= (test-runner-fail-count (test-runner-current)) 0))
+(exit (= 0 exit-status))
 
 ;;; client-server.scm ends here.
