@@ -1,6 +1,6 @@
 ;;; session.scm -- Testing of session procedures without a connection.
 
-;; Copyright (C) 2014, 2015, 2016, 2017, 2018, 2019, 2020 Artyom V. Poptsov <poptsov.artyom@gmail.com>
+;; Copyright (C) 2014-2024 Artyom V. Poptsov <poptsov.artyom@gmail.com>
 ;;
 ;; This file is a part of Guile-SSH.
 ;;
@@ -116,6 +116,12 @@
      options)
     res))
 
+(unless (>= %libssh-minor-version 10)
+  (test-skip "session-set!, rsa-min-size"))
+(test-assert "session-set!, rsa-min-size"
+  (let ((session (%make-session)))
+    (session-set! session 'rsa-min-size 1024)))
+
 (test-assert "session-set!, invalid values"
   (let ((session (%make-session))
         (options '((host              12345 #t)
@@ -224,6 +230,14 @@
   'guile-ssh-error
   (make-session #:config %config))
 
+(test-equal "make-session: keywords must overwrite config options"
+  22
+  (let ((s (make-session #:host   "localhost"
+                         #:port   22
+                         ;; Configuration sets port to 2222
+                         #:config %config)))
+    (session-get s 'port)))
+
 (test-equal-with-log "blocking-flush!"
   'ok
   (blocking-flush! (%make-session) 15))
